Contact

Struct Contact 

pub struct Contact { /* private fields */ }

Implementations

Source

impl Contact

pub fn export_plain(&self) -> Result<Zeroizing<Vec<u8>>, Error>

Export the contact into a versioned, explicit plaintext blob. Caller MUST encrypt this blob before storing/transmitting it. Returns Zeroizing<Vec> so the plaintext will be zeroed on drop.

pub fn import_plain(blob: &[u8]) -> Result<Self, Error>

Import a plaintext blob created by export_plain. The blob MUST have been authenticated and decrypted by the caller before calling this.

Source

impl Contact

pub fn save_backup(&mut self)

pub fn restore_backup(&mut self)

Source

impl Contact

pub fn init_smp( &mut self, question: String, answer: String, ) -> Result<ContactOutput, Error>

pub fn provide_smp_answer( &mut self, answer_struct: UserAnswer, ) -> Result<ContactOutput, Error>

Source

impl Contact

Source

impl Contact

pub fn new() -> Result<Self, Error>

Create new contact

pub fn process(&mut self, data: &[u8]) -> Result<ContactOutput, Error>

Process an incoming blob, returning optional outgoing blob

pub fn process_verified(&mut self, data: &[u8]) -> Result<ContactOutput, Error>